function [ VecSignalspace] = PLDA(Data,Labels,Alpha,nPLDA)
%Penalized LDA calculates the discriminant subspace for the dataset
%   
%Input:
%Data  = The data matrix each column represents one sample 
%Labels= Labels corresponding the data matrix
%Alpha = The weight of PCA in (LDA+Alpha*PCA);
%nPLDA = Number of PLDA directions
%Output: 
%PLDA:   Vector of PLDA directions
%
%Author: Soheil Kolouri
%Date:   09/26/2012

x=mean(Data')';
Data=Data-repmat(x,1,size(Data,2));
[U,S,V]=svd(Data,'econ');
PCAprojection=U'*Data;
nclasses=unique(Labels);
[nfeatures,nsamples]=size(PCAprojection);
SB=zeros(nfeatures,nfeatures);
SW=zeros(nfeatures,nfeatures);
for i=1:length(nclasses)
    Class{i}=PCAprojection(:,Labels==nclasses(i));
    mu(:,i)=mean((Class{i})')';
    Sb{i}=(mu(:,i))*(mu(:,i))';
    Sw{i}=zeros(nfeatures,nfeatures);
    ClassiM=repmat(mu(:,i),1,size(Class{i},2));
    Sw{i}=(Class{i}-ClassiM)*(Class{i}-ClassiM)';    
    SB=SB+(1/nsamples)*size(Class{i},2)*Sb{i};
    SW=SW+(1/nsamples)*Sw{i};
end
ST=SB+SW;
SWNew=SW+(Alpha*nsamples)*eye(size(SW));
[eigvec,eigvalue]=eig(ST,SWNew);
eigvalue(isnan(eigvalue))=0;
eigvalue(abs(eigvalue)==inf)=1e10;
eigval = diag(eigvalue);
[eigval I] = sort((eigval),'descend');
Vec=real(eigvec(:,I(1:nPLDA)));
VecSignalspace=U*Vec;
for i=1:size(Vec,2)
    VecSignalspace(:,i)=VecSignalspace(:,i)/norm(VecSignalspace(:,i));
end
end


