% This code tests CDT and demonstrate interpolation in the CDT space
% Written by Soheil Kolouri, June 4, 2013.
clc
clear
close all
%Since the signals must be positive everywhere we add a small DC level to
%our signal
eps=1e-5; 
%Get a sample image
I=imfilter(phantom,fspecial('gaussian',[15,15],3));
%generate to 1D signals from image projections
I0=sum(I);
I1=sum(I');
%Normalize the signals 
I0=I0/sum(I0)+eps;
I1=I1/sum(I1)+eps;
%Define the grid
N=length(I1);
x=1:N;
%Calculate the mass preserving mapping
[I1CDT,f,df,u,du]=CDT(I0,I1);
%Now morph I1 to I0 using f
Ihat=df.*interp1(x,I1,f,'pchip');
%plot the results
figure
subplot(221)
plot(I1,'linewidth',2)
legend('I_1');
axis square
grid on
set(gca,'fontsize',24)
subplot(222)
plot(I0,'linewidth',4);hold on;plot(Ihat,'linewidth',2)
axis square
grid on
legend('I_0','f''I1(f)');
set(gca,'fontsize',24)
subplot(223)
plot(f,'linewidth',2)
axis square
grid on
legend('f');
set(gca,'fontsize',24)
subplot(224)
plot(f-x,'linewidth',2)
axis square
grid on
legend('u=f-x');
set(gca,'fontsize',24)

%Now show the geodesic
alpha=linspace(1,0,5);
figure
for i=1:5
    falpha=x-alpha(i)*u;
    dfalpha=gradient(falpha);
    Ialpha=dfalpha.*interp1(x,I1,falpha,'pchip');
    subplot(1,5,i)
    plot(Ialpha,'linewidth',2);grid on
    title(['$\alpha=$',num2str(alpha(i))],'interpreter','latex','fontsize',24)
    axis square
    set(gca,'fontsize',18)
    ylim([0,1e-2])
end





